==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsAssociatedOtherSideImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.instanceloading.AttributeChangedDelta;
import io.ciera.runtime.instanceloading.InstanceCreatedDelta;
import io.ciera.runtime.summit.application.IRunContext;
import io.ciera.runtime.summit.classes.IInstanceIdentifier;
import io.ciera.runtime.summit.classes.InstanceIdentifier;
import io.ciera.runtime.summit.classes.ModelInstance;
import io.ciera.runtime.summit.exceptions.EmptyInstanceException;
import io.ciera.runtime.summit.exceptions.InstancePopulationException;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IWhere;
import io.ciera.runtime.summit.types.StringUtil;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSide;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociation;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssoc;
import io.ciera.tool.sql.ooaofooa.association.impl.LinkedAssociationImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocImpl;


public class ClassAsAssociatedOtherSideImpl extends ModelInstance<ClassAsAssociatedOtherSide,Sql> implements ClassAsAssociatedOtherSide {

    public static final String KEY_LETTERS = "R_AOTH";
    public static final ClassAsAssociatedOtherSide EMPTY_CLASSASASSOCIATEDOTHERSIDE = new EmptyClassAsAssociatedOtherSide();

    private Sql context;

    // constructors
    private ClassAsAssociatedOtherSideImpl( Sql context ) {
        this.context = context;
        ref_Obj_ID = UniqueId.random();
        ref_Rel_ID = UniqueId.random();
        ref_OIR_ID = UniqueId.random();
        m_Mult = 0;
        m_Cond = 0;
        m_Txt_Phrs = "";
        R204_is_a_ReferredToClassInAssoc_inst = ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
        R210_is_related_to_one_side_via_LinkedAssociation_inst = LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }

    private ClassAsAssociatedOtherSideImpl( Sql context, UniqueId instanceId, UniqueId ref_Obj_ID, UniqueId ref_Rel_ID, UniqueId ref_OIR_ID, int m_Mult, int m_Cond, String m_Txt_Phrs ) {
        super(instanceId);
        this.context = context;
        this.ref_Obj_ID = ref_Obj_ID;
        this.ref_Rel_ID = ref_Rel_ID;
        this.ref_OIR_ID = ref_OIR_ID;
        this.m_Mult = m_Mult;
        this.m_Cond = m_Cond;
        this.m_Txt_Phrs = m_Txt_Phrs;
        R204_is_a_ReferredToClassInAssoc_inst = ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
        R210_is_related_to_one_side_via_LinkedAssociation_inst = LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }

    public static ClassAsAssociatedOtherSide create( Sql context ) throws XtumlException {
        ClassAsAssociatedOtherSide newClassAsAssociatedOtherSide = new ClassAsAssociatedOtherSideImpl( context );
        if ( context.addInstance( newClassAsAssociatedOtherSide ) ) {
            newClassAsAssociatedOtherSide.getRunContext().addChange(new InstanceCreatedDelta(newClassAsAssociatedOtherSide, KEY_LETTERS));
            return newClassAsAssociatedOtherSide;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }

    public static ClassAsAssociatedOtherSide create( Sql context, UniqueId instanceId, UniqueId ref_Obj_ID, UniqueId ref_Rel_ID, UniqueId ref_OIR_ID, int m_Mult, int m_Cond, String m_Txt_Phrs ) throws XtumlException {
        ClassAsAssociatedOtherSide newClassAsAssociatedOtherSide = new ClassAsAssociatedOtherSideImpl( context, instanceId, ref_Obj_ID, ref_Rel_ID, ref_OIR_ID, m_Mult, m_Cond, m_Txt_Phrs );
        if ( context.addInstance( newClassAsAssociatedOtherSide ) ) {
            return newClassAsAssociatedOtherSide;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }



    // attributes
    private UniqueId ref_Obj_ID;
    @Override
    public UniqueId getObj_ID() throws XtumlException {
        checkLiving();
                return ref_Obj_ID;
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        checkLiving();
        if ( ref_Obj_ID.inequality( this.ref_Obj_ID ) ) {
            final UniqueId oldValue = this.ref_Obj_ID;
            this.ref_Obj_ID = ref_Obj_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Obj_ID", oldValue, this.ref_Obj_ID));
        }
    }
    private UniqueId ref_Rel_ID;
    @Override
    public UniqueId getRel_ID() throws XtumlException {
        checkLiving();
                return ref_Rel_ID;
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        checkLiving();
        if ( ref_Rel_ID.inequality( this.ref_Rel_ID ) ) {
            final UniqueId oldValue = this.ref_Rel_ID;
            this.ref_Rel_ID = ref_Rel_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Rel_ID", oldValue, this.ref_Rel_ID));
        }
    }
    private UniqueId ref_OIR_ID;
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        checkLiving();
        if ( ref_OIR_ID.inequality( this.ref_OIR_ID ) ) {
            final UniqueId oldValue = this.ref_OIR_ID;
            this.ref_OIR_ID = ref_OIR_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_OIR_ID", oldValue, this.ref_OIR_ID));
        }
    }
    @Override
    public UniqueId getOIR_ID() throws XtumlException {
        checkLiving();
                return ref_OIR_ID;
    }
    private int m_Mult;
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        checkLiving();
        if ( m_Mult != this.m_Mult ) {
            final int oldValue = this.m_Mult;
            this.m_Mult = m_Mult;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Mult", oldValue, this.m_Mult));
        }
    }
    @Override
    public int getMult() throws XtumlException {
        checkLiving();
                return m_Mult;
    }
    private int m_Cond;
    @Override
    public int getCond() throws XtumlException {
        checkLiving();
                return m_Cond;
    }
    @Override
    public void setCond( int m_Cond ) throws XtumlException {
        checkLiving();
        if ( m_Cond != this.m_Cond ) {
            final int oldValue = this.m_Cond;
            this.m_Cond = m_Cond;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Cond", oldValue, this.m_Cond));
        }
    }
    private String m_Txt_Phrs;
    @Override
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        checkLiving();
        if ( StringUtil.inequality( m_Txt_Phrs, this.m_Txt_Phrs ) ) {
            final String oldValue = this.m_Txt_Phrs;
            this.m_Txt_Phrs = m_Txt_Phrs;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Txt_Phrs", oldValue, this.m_Txt_Phrs));
        }
    }
    @Override
    public String getTxt_Phrs() throws XtumlException {
        checkLiving();
                return m_Txt_Phrs;
    }


    // instance identifiers
    @Override
    public IInstanceIdentifier getId1() {
        try {
            return new InstanceIdentifier(getObj_ID(), getRel_ID(), getOIR_ID());
        }
        catch ( XtumlException e ) {
            getRunContext().getLog().error(e);
            System.exit(1);
            return null;
        }
    }

    // operations


    // static operations


    // events


    // selections
    private ReferredToClassInAssoc R204_is_a_ReferredToClassInAssoc_inst;
    @Override
    public void setR204_is_a_ReferredToClassInAssoc( ReferredToClassInAssoc inst ) {
        R204_is_a_ReferredToClassInAssoc_inst = inst;
    }
    @Override
    public ReferredToClassInAssoc R204_is_a_ReferredToClassInAssoc() throws XtumlException {
        return R204_is_a_ReferredToClassInAssoc_inst;
    }
    private LinkedAssociation R210_is_related_to_one_side_via_LinkedAssociation_inst;
    @Override
    public void setR210_is_related_to_one_side_via_LinkedAssociation( LinkedAssociation inst ) {
        R210_is_related_to_one_side_via_LinkedAssociation_inst = inst;
    }
    @Override
    public LinkedAssociation R210_is_related_to_one_side_via_LinkedAssociation() throws XtumlException {
        return R210_is_related_to_one_side_via_LinkedAssociation_inst;
    }


    @Override
    public IRunContext getRunContext() {
        return context().getRunContext();
    }

    @Override
    public Sql context() {
        return context;
    }

    @Override
    public String getKeyLetters() {
        return KEY_LETTERS;
    }

    @Override
    public ClassAsAssociatedOtherSide value() {
        return this;
    }

    @Override
    public ClassAsAssociatedOtherSide self() {
        return this;
    }

    @Override
    public ClassAsAssociatedOtherSide oneWhere( IWhere<ClassAsAssociatedOtherSide> condition ) throws XtumlException {
        if ( null == condition ) throw new XtumlException( "Null condition passed to selection." );
        if ( condition.evaluate( value() ) ) return value();
        else return EMPTY_CLASSASASSOCIATEDOTHERSIDE;
    }

}

class EmptyClassAsAssociatedOtherSide extends ModelInstance<ClassAsAssociatedOtherSide,Sql> implements ClassAsAssociatedOtherSide {

    // attributes
    public UniqueId getObj_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getRel_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getOIR_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setMult( int m_Mult ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public int getMult() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public int getCond() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setCond( int m_Cond ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public String getTxt_Phrs() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }


    // operations


    // selections
    @Override
    public ReferredToClassInAssoc R204_is_a_ReferredToClassInAssoc() {
        return ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
    }
    @Override
    public LinkedAssociation R210_is_related_to_one_side_via_LinkedAssociation() {
        return LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }


    @Override
    public String getKeyLetters() {
        return ClassAsAssociatedOtherSideImpl.KEY_LETTERS;
    }

    @Override
    public ClassAsAssociatedOtherSide value() {
        return this;
    }
    
    @Override
    public ClassAsAssociatedOtherSide self() {
        return this;
    }

    @Override
    public boolean isEmpty() {
        return true;
    }

    @Override
    public ClassAsAssociatedOtherSide oneWhere( IWhere<ClassAsAssociatedOtherSide> condition ) throws XtumlException {
        if ( null == condition ) throw new XtumlException( "Null condition passed to selection." );
        return ClassAsAssociatedOtherSideImpl.EMPTY_CLASSASASSOCIATEDOTHERSIDE;
    }

}

==> tool-sql-2.3.0-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsAssociatedOtherSideImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.instanceloading.AttributeChangedDelta;
import io.ciera.runtime.instanceloading.InstanceCreatedDelta;
import io.ciera.runtime.summit.application.IRunContext;
import io.ciera.runtime.summit.classes.IInstanceIdentifier;
import io.ciera.runtime.summit.classes.InstanceIdentifier;
import io.ciera.runtime.summit.classes.ModelInstance;
import io.ciera.runtime.summit.exceptions.EmptyInstanceException;
import io.ciera.runtime.summit.exceptions.InstancePopulationException;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IWhere;
import io.ciera.runtime.summit.types.IXtumlType;
import io.ciera.runtime.summit.types.StringUtil;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.association.ClassAsAssociatedOtherSide;
import io.ciera.tool.sql.ooaofooa.association.LinkedAssociation;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssoc;
import io.ciera.tool.sql.ooaofooa.association.impl.LinkedAssociationImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocImpl;


public class ClassAsAssociatedOtherSideImpl extends ModelInstance<ClassAsAssociatedOtherSide,Sql> implements ClassAsAssociatedOtherSide {

    public static final String KEY_LETTERS = "R_AOTH";
    public static final ClassAsAssociatedOtherSide EMPTY_CLASSASASSOCIATEDOTHERSIDE = new EmptyClassAsAssociatedOtherSide();

    private Sql context;

    // constructors
    private ClassAsAssociatedOtherSideImpl( Sql context ) {
        this.context = context;
        ref_Obj_ID = UniqueId.random();
        ref_Rel_ID = UniqueId.random();
        ref_OIR_ID = UniqueId.random();
        m_Mult = 0;
        m_Cond = 0;
        m_Txt_Phrs = "";
        R204_is_a_ReferredToClassInAssoc_inst = ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
        R210_is_related_to_one_side_via_LinkedAssociation_inst = LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }

    private ClassAsAssociatedOtherSideImpl( Sql context, UniqueId instanceId, UniqueId ref_Obj_ID, UniqueId ref_Rel_ID, UniqueId ref_OIR_ID, int m_Mult, int m_Cond, String m_Txt_Phrs ) {
        super(instanceId);
        this.context = context;
        this.ref_Obj_ID = ref_Obj_ID;
        this.ref_Rel_ID = ref_Rel_ID;
        this.ref_OIR_ID = ref_OIR_ID;
        this.m_Mult = m_Mult;
        this.m_Cond = m_Cond;
        this.m_Txt_Phrs = m_Txt_Phrs;
        R204_is_a_ReferredToClassInAssoc_inst = ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
        R210_is_related_to_one_side_via_LinkedAssociation_inst = LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }

    public static ClassAsAssociatedOtherSide create( Sql context ) throws XtumlException {
        ClassAsAssociatedOtherSide newClassAsAssociatedOtherSide = new ClassAsAssociatedOtherSideImpl( context );
        if ( context.addInstance( newClassAsAssociatedOtherSide ) ) {
            newClassAsAssociatedOtherSide.getRunContext().addChange(new InstanceCreatedDelta(newClassAsAssociatedOtherSide, KEY_LETTERS));
            return newClassAsAssociatedOtherSide;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }

    public static ClassAsAssociatedOtherSide create( Sql context, UniqueId instanceId, UniqueId ref_Obj_ID, UniqueId ref_Rel_ID, UniqueId ref_OIR_ID, int m_Mult, int m_Cond, String m_Txt_Phrs ) throws XtumlException {
        ClassAsAssociatedOtherSide newClassAsAssociatedOtherSide = new ClassAsAssociatedOtherSideImpl( context, instanceId, ref_Obj_ID, ref_Rel_ID, ref_OIR_ID, m_Mult, m_Cond, m_Txt_Phrs );
        if ( context.addInstance( newClassAsAssociatedOtherSide ) ) {
            return newClassAsAssociatedOtherSide;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }



    // attributes
    private UniqueId ref_Obj_ID;
    @Override
    public UniqueId getObj_ID() throws XtumlException {
        checkLiving();
        return ref_Obj_ID;
    }
    @Override
    public void setObj_ID(UniqueId ref_Obj_ID) throws XtumlException {
        checkLiving();
        if (ref_Obj_ID.inequality( this.ref_Obj_ID)) {
            final UniqueId oldValue = this.ref_Obj_ID;
            this.ref_Obj_ID = ref_Obj_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Obj_ID", oldValue, this.ref_Obj_ID));
        }
    }
    private UniqueId ref_Rel_ID;
    @Override
    public UniqueId getRel_ID() throws XtumlException {
        checkLiving();
        return ref_Rel_ID;
    }
    @Override
    public void setRel_ID(UniqueId ref_Rel_ID) throws XtumlException {
        checkLiving();
        if (ref_Rel_ID.inequality( this.ref_Rel_ID)) {
            final UniqueId oldValue = this.ref_Rel_ID;
            this.ref_Rel_ID = ref_Rel_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Rel_ID", oldValue, this.ref_Rel_ID));
        }
    }
    private UniqueId ref_OIR_ID;
    @Override
    public void setOIR_ID(UniqueId ref_OIR_ID) throws XtumlException {
        checkLiving();
        if (ref_OIR_ID.inequality( this.ref_OIR_ID)) {
            final UniqueId oldValue = this.ref_OIR_ID;
            this.ref_OIR_ID = ref_OIR_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_OIR_ID", oldValue, this.ref_OIR_ID));
        }
    }
    @Override
    public UniqueId getOIR_ID() throws XtumlException {
        checkLiving();
        return ref_OIR_ID;
    }
    private int m_Mult;
    @Override
    public void setMult(int m_Mult) throws XtumlException {
        checkLiving();
        if (m_Mult != this.m_Mult) {
            final int oldValue = this.m_Mult;
            this.m_Mult = m_Mult;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Mult", oldValue, this.m_Mult));
        }
    }
    @Override
    public int getMult() throws XtumlException {
        checkLiving();
        return m_Mult;
    }
    private int m_Cond;
    @Override
    public void setCond(int m_Cond) throws XtumlException {
        checkLiving();
        if (m_Cond != this.m_Cond) {
            final int oldValue = this.m_Cond;
            this.m_Cond = m_Cond;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Cond", oldValue, this.m_Cond));
        }
    }
    @Override
    public int getCond() throws XtumlException {
        checkLiving();
        return m_Cond;
    }
    private String m_Txt_Phrs;
    @Override
    public void setTxt_Phrs(String m_Txt_Phrs) throws XtumlException {
        checkLiving();
        if (StringUtil.inequality(m_Txt_Phrs, this.m_Txt_Phrs)) {
            final String oldValue = this.m_Txt_Phrs;
            this.m_Txt_Phrs = m_Txt_Phrs;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Txt_Phrs", oldValue, this.m_Txt_Phrs));
        }
    }
    @Override
    public String getTxt_Phrs() throws XtumlException {
        checkLiving();
        return m_Txt_Phrs;
    }


    // instance identifiers
    @Override
    public IInstanceIdentifier getId1() {
        try {
            return new InstanceIdentifier(getObj_ID(), getRel_ID(), getOIR_ID());
        }
        catch ( XtumlException e ) {
            getRunContext().getLog().error(e);
            System.exit(1);
            return null;
        }
    }

    // operations


    // static operations


    // events


    // selections
    private ReferredToClassInAssoc R204_is_a_ReferredToClassInAssoc_inst;
    @Override
    public void setR204_is_a_ReferredToClassInAssoc( ReferredToClassInAssoc inst ) {
        R204_is_a_ReferredToClassInAssoc_inst = inst;
    }
    @Override
    public ReferredToClassInAssoc R204_is_a_ReferredToClassInAssoc() throws XtumlException {
        return R204_is_a_ReferredToClassInAssoc_inst;
    }
    private LinkedAssociation R210_is_related_to_one_side_via_LinkedAssociation_inst;
    @Override
    public void setR210_is_related_to_one_side_via_LinkedAssociation( LinkedAssociation inst ) {
        R210_is_related_to_one_side_via_LinkedAssociation_inst = inst;
    }
    @Override
    public LinkedAssociation R210_is_related_to_one_side_via_LinkedAssociation() throws XtumlException {
        return R210_is_related_to_one_side_via_LinkedAssociation_inst;
    }


    @Override
    public IRunContext getRunContext() {
        return context().getRunContext();
    }

    @Override
    public Sql context() {
        return context;
    }

    @Override
    public String getKeyLetters() {
        return KEY_LETTERS;
    }

    @Override
    public ClassAsAssociatedOtherSide self() {
        return this;
    }

    @Override
    public ClassAsAssociatedOtherSide oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        if (condition.evaluate(this)) return this;
        else return EMPTY_CLASSASASSOCIATEDOTHERSIDE;
    }

}

class EmptyClassAsAssociatedOtherSide extends ModelInstance<ClassAsAssociatedOtherSide,Sql> implements ClassAsAssociatedOtherSide {

    // attributes
    public UniqueId getObj_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getRel_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getOIR_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setMult( int m_Mult ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public int getMult() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setCond( int m_Cond ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public int getCond() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public String getTxt_Phrs() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }


    // operations


    // selections
    @Override
    public ReferredToClassInAssoc R204_is_a_ReferredToClassInAssoc() {
        return ReferredToClassInAssocImpl.EMPTY_REFERREDTOCLASSINASSOC;
    }
    @Override
    public LinkedAssociation R210_is_related_to_one_side_via_LinkedAssociation() {
        return LinkedAssociationImpl.EMPTY_LINKEDASSOCIATION;
    }


    @Override
    public String getKeyLetters() {
        return ClassAsAssociatedOtherSideImpl.KEY_LETTERS;
    }

    @Override
    public ClassAsAssociatedOtherSide self() {
        return this;
    }

    @Override
    public boolean isEmpty() {
        return true;
    }

    @Override
    public ClassAsAssociatedOtherSide oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        return ClassAsAssociatedOtherSideImpl.EMPTY_CLASSASASSOCIATEDOTHERSIDE;
    }

}
